package com.ruoyi.report.service;

import java.util.List;
import com.ruoyi.report.domain.RecordWorkprocedureamountDay;

/**
 * 工序产量日报Service接口
 * 
 * @author CaesarBao
 * @date 2020-11-03
 */
public interface IRecordWorkprocedureamountDayService 
{
    /**
     * 查询工序产量日报
     * 
     * @param objid 工序产量日报ID
     * @return 工序产量日报
     */
    public RecordWorkprocedureamountDay selectRecordWorkprocedureamountDayById(Long objid);

    /**
     * 查询工序产量日报列表
     * 
     * @param recordWorkprocedureamountDay 工序产量日报
     * @return 工序产量日报集合
     */
    public List<RecordWorkprocedureamountDay> selectRecordWorkprocedureamountDayList(RecordWorkprocedureamountDay recordWorkprocedureamountDay);

    /**
     * 新增工序产量日报
     * 
     * @param recordWorkprocedureamountDay 工序产量日报
     * @return 结果
     */
    public int insertRecordWorkprocedureamountDay(RecordWorkprocedureamountDay recordWorkprocedureamountDay);

    /**
     * 修改工序产量日报
     * 
     * @param recordWorkprocedureamountDay 工序产量日报
     * @return 结果
     */
    public int updateRecordWorkprocedureamountDay(RecordWorkprocedureamountDay recordWorkprocedureamountDay);

    /**
     * 批量删除工序产量日报
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteRecordWorkprocedureamountDayByIds(String ids);

    /**
     * 删除工序产量日报信息
     * 
     * @param objid 工序产量日报ID
     * @return 结果
     */
    public int deleteRecordWorkprocedureamountDayById(Long objid);
}
